summaryrefslogtreecommitdiffstats
path: root/src/basketfactory.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/basketfactory.cpp')
-rw-r--r--src/basketfactory.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/basketfactory.cpp b/src/basketfactory.cpp
index 1873047..ed01301 100644
--- a/src/basketfactory.cpp
+++ b/src/basketfactory.cpp
@@ -57,7 +57,7 @@ TQString BasketFactory::unpackTemplate(const TQString &templateName)
TQString fullPath = Global::basketsFolder() + folderName;
TQDir dir;
if (!dir.mkdir(fullPath)) {
- KMessageBox::error(/*tqparent=*/0, i18n("Sorry, but the folder creation for this new basket has failed."), i18n("Basket Creation Failed"));
+ KMessageBox::error(/*parent=*/0, i18n("Sorry, but the folder creation for this new basket has failed."), i18n("Basket Creation Failed"));
return "";
}
@@ -87,7 +87,7 @@ TQString BasketFactory::unpackTemplate(const TQString &templateName)
file.close();
return folderName;
} else {
- KMessageBox::error(/*tqparent=*/0, i18n("Sorry, but the template copying for this new basket has failed."), i18n("Basket Creation Failed"));
+ KMessageBox::error(/*parent=*/0, i18n("Sorry, but the template copying for this new basket has failed."), i18n("Basket Creation Failed"));
return "";
}
}
@@ -98,7 +98,7 @@ void BasketFactory::newBasket(const TQString &icon,
const TQColor &backgroundColor,
const TQColor &textColor,
const TQString &templateName,
- Basket *tqparent)
+ Basket *parent)
{
// Unpack the templateName file to a new basket folder:
TQString folderName = unpackTemplate(templateName);
@@ -108,7 +108,7 @@ void BasketFactory::newBasket(const TQString &icon,
// Read the properties, change those that should be customized and save the result:
TQDomDocument *document = XMLWork::openFile("basket", Global::basketsFolder() + folderName + "/.basket");
if (!document) {
- KMessageBox::error(/*tqparent=*/0, i18n("Sorry, but the template customization for this new basket has failed."), i18n("Basket Creation Failed"));
+ KMessageBox::error(/*parent=*/0, i18n("Sorry, but the template customization for this new basket has failed."), i18n("Basket Creation Failed"));
return;
}
TQDomElement properties = XMLWork::getElement(document->documentElement(), "properties");
@@ -154,6 +154,6 @@ void BasketFactory::newBasket(const TQString &icon,
appearanceElement.setAttribute("textColor", textColor.name());
}
- // Load it in the tqparent basket (it will save the tree and switch to this new basket):
- Global::bnpView->loadNewBasket(folderName, properties, tqparent);
+ // Load it in the parent basket (it will save the tree and switch to this new basket):
+ Global::bnpView->loadNewBasket(folderName, properties, parent);
}